@@ -100,7 +100,7 @@ public interface GroupManager {
 	 * @return the virtual group name associated to this group
 	 * @throws GroupRetrievalFault
 	 */
-	VirtualGroup getVirtualGroup(long actualGroupId) throws GroupRetrievalFault, VirtualGroupNotExistingException;
+	List<VirtualGroup> getVirtualGroups(long actualGroupId) throws GroupRetrievalFault, VirtualGroupNotExistingException;
 	/*
 	 * 
 	 * @param scope the infrastructure scope e.g. /gcube/devsec
