@@ -51,6 +51,9 @@ import com.liferay.portlet.expando.model.ExpandoBridge;
 import com.liferay.portlet.expando.util.ExpandoBridgeFactoryUtil;
 
 public class LiferayGroupManager implements GroupManager {
+	
+	private static final String DEFAULT_INFRA_NAME = "gcube";
+	public static final String INFRASTRUCTURE_NAME = "infrastructure";
 	/**
 	 * logger
 	 */
@@ -136,28 +139,32 @@ public class LiferayGroupManager implements GroupManager {
 	 * {@inheritDoc}
 	 */
 	@Override
-	public VirtualGroup getVirtualGroup(long actualGroupId) throws GroupRetrievalFault, VirtualGroupNotExistingException {
-		VirtualGroup toReturn = new VirtualGroup();
+	public List<VirtualGroup> getVirtualGroups(long actualGroupId) throws GroupRetrievalFault, VirtualGroupNotExistingException {
+		List<VirtualGroup> toReturn = new ArrayList<VirtualGroup>();
 		try {
 			long userId = LiferayUserManager.getAdmin().getUserId();
 			PrincipalThreadLocal.setName(userId);
 			PermissionChecker permissionChecker = PermissionCheckerFactoryUtil.create(UserLocalServiceUtil.getUser(userId));
 			PermissionThreadLocal.setPermissionChecker(permissionChecker); 
 			Group site = GroupLocalServiceUtil.getGroup(actualGroupId);
-			_log.debug("Set Thread Permission done, getVirtual Group of " + site.getName());
 			if (site.getExpandoBridge().getAttribute(CustomAttributeKeys.VIRTUAL_GROUP.getKeyName()) == null ||  site.getExpandoBridge().getAttribute(CustomAttributeKeys.VIRTUAL_GROUP.getKeyName()).equals("")) {
 				String warningMessage = String.format("Attribute %s not initialized.", CustomAttributeKeys.VIRTUAL_GROUP.getKeyName());
 				_log.warn(warningMessage); 
 				throw new VirtualGroupNotExistingException(warningMessage);
 			} else {
 				String[] values = (String[]) site.getExpandoBridge().getAttribute(CustomAttributeKeys.VIRTUAL_GROUP.getKeyName());  
+				VirtualGroup toAdd = new VirtualGroup();
 				if (values != null && values.length > 0) {
-					String[] splits = values[0].split("\\|");
-					toReturn.setName(splits[0]);
-					toReturn.setDescription(splits[1]);
+					for (int i = 0; i < values.length; i++) {
+						toAdd = new VirtualGroup();
+						String[] splits = values[i].split("\\|");
+						toAdd.setName(splits[0]);
+						toAdd.setDescription(splits[1]);
+						toReturn.add(toAdd);
+					}					
 				} else {
-					toReturn.setName("NoVirtualGroupAssigned");
-					toReturn.setDescription("NoVirtualGroupDescription");
+					toAdd.setName("NoVirtualGroupAssigned");
+					toAdd.setDescription("NoVirtualGroupDescription");
 				}
 			}
 		} catch (Exception e) {
@@ -414,14 +421,20 @@ public class LiferayGroupManager implements GroupManager {
 	public Set<GCubeGroup> listGroupsByUserAndSite(long userId, final String serverName) throws UserRetrievalFault, UserManagementSystemException, GroupRetrievalFault, VirtualGroupNotExistingException {
 		Set<GCubeGroup> toReturn = new HashSet<>();
 		try {
-			List<VirtualGroup> currSiteVirtualGroups = ManagementUtils.getVirtualGroupsBySiteGroupId(ManagementUtils.getSiteGroupIdFromServletRequest(serverName));
+			List<VirtualGroup> currSiteVirtualGroups = getVirtualGroups(ManagementUtils.getSiteGroupIdFromServletRequest(serverName));
+					
 			for (GCubeGroup userGroup : listGroupsByUser(userId)) {
 				if (isVRE(userGroup.getGroupId())) {
-					for (VirtualGroup vg : currSiteVirtualGroups) 
-						if (getVirtualGroup(userGroup.getGroupId()).getName().compareTo(vg.getName()) == 0) 
-							toReturn.add(userGroup);
+					for (VirtualGroup currSiteVGroup : currSiteVirtualGroups) {
+						List<VirtualGroup> vGroups = getVirtualGroups(userGroup.getGroupId());
+						for (VirtualGroup virtualGroup : vGroups) {
+							if (virtualGroup.getName().compareTo(currSiteVGroup.getName()) == 0) 
+								toReturn.add(userGroup);
+						}						
+					}
 				}
 			}
+			
 		} catch (Exception e) {
 			e.printStackTrace();
 		}		
@@ -609,8 +622,40 @@ public class LiferayGroupManager implements GroupManager {
 			e.printStackTrace();
 		}
 	}
-	private static final String DEFAULT_INFRA_NAME = "gcube";
-	public static final String INFRASTRUCTURE_NAME = "infrastructure";
+	@Deprecated 
+	/**
+	 * to be removed in the next release
+	 */
+	private VirtualGroup getVirtualGroup(long actualGroupId) throws GroupRetrievalFault, VirtualGroupNotExistingException {
+		VirtualGroup toReturn = new VirtualGroup();
+		try {
+			long userId = LiferayUserManager.getAdmin().getUserId();
+			PrincipalThreadLocal.setName(userId);
+			PermissionChecker permissionChecker = PermissionCheckerFactoryUtil.create(UserLocalServiceUtil.getUser(userId));
+			PermissionThreadLocal.setPermissionChecker(permissionChecker); 
+			Group site = GroupLocalServiceUtil.getGroup(actualGroupId);
+			_log.debug("Set Thread Permission done, getVirtual Group of " + site.getName());
+			if (site.getExpandoBridge().getAttribute(CustomAttributeKeys.VIRTUAL_GROUP.getKeyName()) == null ||  site.getExpandoBridge().getAttribute(CustomAttributeKeys.VIRTUAL_GROUP.getKeyName()).equals("")) {
+				String warningMessage = String.format("Attribute %s not initialized.", CustomAttributeKeys.VIRTUAL_GROUP.getKeyName());
+				_log.warn(warningMessage); 
+				throw new VirtualGroupNotExistingException(warningMessage);
+			} else {
+				String[] values = (String[]) site.getExpandoBridge().getAttribute(CustomAttributeKeys.VIRTUAL_GROUP.getKeyName());  
+				if (values != null && values.length > 0) {
+					String[] splits = values[0].split("\\|");
+					toReturn.setName(splits[0]);
+					toReturn.setDescription(splits[1]);
+				} else {
+					toReturn.setName("NoVirtualGroupAssigned");
+					toReturn.setDescription("NoVirtualGroupDescription");
+				}
+			}
+		} catch (Exception e) {
+			e.printStackTrace();
+		}
+		return toReturn;
+	}
+
 	/**
 	 * read the infrastructure name from a property file and returns it
 	 */
